Skip to contents

Identifies the most recent AWS index file (all years) within the given number of days.

Usage

find_current_index_full(days = 100)

Arguments

days

An integer specifying the number of past days to check.

Value

A character string representing the URL of the most recent index file, or NA if none found.

Examples

find_current_index_full(100)
#> [1] "https://gt990datalake-rawdata.s3.us-east-1.amazonaws.com/Indices/990xmls/index_all_years_efiledata_xmls_created_on_2026-06-04.csv"