Find Most Recent Date
find_most_recent_date.RdFinds the position of the most recent date in a vector of dates.
Examples
dates <- c( "2023-11-18", "2023-11-19", "2024-06-01" )
find_most_recent_date( dates )
#> [1] 3
find_most_recent_date.RdFinds the position of the most recent date in a vector of dates.
dates <- c( "2023-11-18", "2023-11-19", "2024-06-01" )
find_most_recent_date( dates )
#> [1] 3