Create a named list from its arguments
namedList.RdConstructs a list whose names are taken from the supplied argument
expressions. Empty or NULL elements are replaced with NA.
namedList.RdConstructs a list whose names are taken from the supplied argument
expressions. Empty or NULL elements are replaced with NA.