Extract text from XML nodes
retrieve_xml.RdRetrieves the text content of all nodes matching an XPath expression.
Arguments
- doc
An XML document object (from
xml2::read_xml()).- TEMP_VAR
Character. XPath expression specifying the nodes to retrieve.
retrieve_xml.RdRetrieves the text content of all nodes matching an XPath expression.
An XML document object (from xml2::read_xml()).
Character. XPath expression specifying the nodes to retrieve.