Create Edgelist Version 1
create_edgelist_v1.RdCreates an edgelist from XPath expressions by splitting them into hierarchical node pairs.
Value
A data frame containing the edgelist with two columns representing parent-child relationships.
Examples
create_edgelist_v1(c("/A/B/C", "/A/D/E"))
#> V1 V2
#> 1 A B
#> 2 B C
#> 3 A D
#> 4 D E