extract_functions.Rd
Parses an R script to identify function definitions and their arguments.
extract_functions(file)
A character string specifying the path to an R script file.
A data frame containing function names and their respective arguments.
if (FALSE) { # \dontrun{ extract_functions("script.R") } # }