Find Most Recent AWS Batch Index
find_current_index_batch.RdIdentifies the most recent AWS batch index file within the given number of days (only new files).
find_current_index_batch.RdIdentifies the most recent AWS batch index file within the given number of days (only new files).