get_attr_df.Rd
Each attribute is returned as one row with columns: OBJECTID, node_name, xpath, attr_name, and attr_value.
get_attr_df(doc, url)
Parsed XML document (xml2::read_xml()).
Source URL of the XML file (used to derive OBJECTID).
A tidy data frame with one row per attribute.