Inspect a DuckDB database interactively
inspect_ddb.RdLists all tables in a DuckDB file, showing their dimensions and sample
contents. If a specific table name is provided, previews the first n
rows from that table.
inspect_ddb.RdLists all tables in a DuckDB file, showing their dimensions and sample
contents. If a specific table name is provided, previews the first n
rows from that table.